@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2008	PgPool Global Development Group
+ * Copyright (c) 2003-2010	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -29,6 +29,7 @@
 #include <stdlib.h>
 
 #include "pool.h"
+#include "pool_config.h"
 
 #define MAXSTRFTIME 128
 
@@ -41,6 +42,7 @@ void pool_error(const char *fmt,...)
 	va_list		ap;
 #ifdef HAVE_ASPRINTF
 	char		*fmt2;
+    int         len;
 #endif
 
 #ifdef HAVE_SIGPROCMASK
@@ -53,11 +55,11 @@ void pool_error(const char *fmt,...)
 
 	if (pool_config->print_timestamp)
 #ifdef HAVE_ASPRINTF
-	  asprintf(&fmt2, "%s ERROR: pid %d: %s\n", nowsec(), (int)getpid(), fmt);
+	  len = asprintf(&fmt2, "%s ERROR: pid %d: %s\n", nowsec(), (int)getpid(), fmt);
 	else
-	  asprintf(&fmt2, "ERROR: pid %d: %s\n", (int)getpid(), fmt);
+	  len = asprintf(&fmt2, "ERROR: pid %d: %s\n", (int)getpid(), fmt);
 
-   if (fmt2)
+   if (len >= 0 && fmt2)
    {
      va_start(ap, fmt);
      vfprintf(stderr, fmt2, ap);
@@ -84,6 +86,7 @@ void pool_debug(const char *fmt,...)
 	va_list		ap;
 #ifdef HAVE_ASPRINTF
 	char		*fmt2;
+    int         len;
 #endif
 
 #ifdef HAVE_SIGPROCMASK
@@ -92,18 +95,26 @@ void pool_debug(const char *fmt,...)
 	int	oldmask;
 #endif
 
-	if (!debug)
-		return;
+	if (run_as_pcp_child)
+	{
+		if (!debug)
+			return;
+	}
+	else
+	{
+		if (pool_config->debug_level <= 0)
+			return;
+	}
 
 	POOL_SETMASK2(&BlockSig, &oldmask);
 
 	if (pool_config->print_timestamp)
 #ifdef HAVE_ASPRINTF
-	  asprintf(&fmt2, "%s DEBUG: pid %d: %s\n", nowsec(), (int)getpid(), fmt);
+	  len = asprintf(&fmt2, "%s DEBUG: pid %d: %s\n", nowsec(), (int)getpid(), fmt);
 	else
-	  asprintf(&fmt2, "DEBUG: pid %d: %s\n", (int)getpid(), fmt);
+	  len = asprintf(&fmt2, "DEBUG: pid %d: %s\n", (int)getpid(), fmt);
 
-   if (fmt2)
+   if (len >= 0 && fmt2)
    {
      va_start(ap, fmt);
      vfprintf(stderr, fmt2, ap);
@@ -130,6 +141,7 @@ void pool_log(const char *fmt,...)
 	va_list		ap;
 #ifdef HAVE_ASPRINTF
 	char		*fmt2;
+    int         len;
 #endif
 
 #ifdef HAVE_SIGPROCMASK
@@ -142,11 +154,11 @@ void pool_log(const char *fmt,...)
 
 	if (pool_config->print_timestamp)
 #ifdef HAVE_ASPRINTF
-	  asprintf(&fmt2, "%s LOG:   pid %d: %s\n", nowsec(), (int)getpid(), fmt);
+	  len = asprintf(&fmt2, "%s LOG:   pid %d: %s\n", nowsec(), (int)getpid(), fmt);
 	else
-	  asprintf(&fmt2, "LOG:   pid %d: %s\n", (int)getpid(), fmt);
+	  len = asprintf(&fmt2, "LOG:   pid %d: %s\n", (int)getpid(), fmt);
 
-   if (fmt2)
+   if (len >= 0 && fmt2)
    {
      va_start(ap, fmt);
      vfprintf(stderr, fmt2, ap);
