@@ -1,12 +1,12 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /cvsroot/pgpool/pgpool-II/pool_query_context.h,v 1.8 2010/07/21 04:33:59 kitagawa Exp $
+ * $Header$
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2010	PgPool Global Development Group
+ * Copyright (c) 2003-2011	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -31,6 +31,13 @@
 #include "parser/nodes.h"
 #include "parser/pool_memory.h"
 
+typedef enum {
+	POOL_UNPARSED,
+	POOL_PARSE_COMPLETE,
+	POOL_BIND_COMPLETE,
+	POOL_EXECUTE_COMPLETE
+} POOL_QUERY_STATE;
+
 /*
  * Query context:
  * Manages per query context
@@ -38,19 +45,12 @@
 typedef struct {
 	char *original_query;		/* original query string */
 	char *rewritten_query;		/* rewritten query string if any */
-	Node *parse_tree;	/* raw parser output if any */
+	Node *parse_tree;			/* raw parser output if any */
 	Node *rewritten_parse_tree;	/* rewritten raw parser output if any */
-	bool where_to_send[MAX_NUM_BACKENDS];		/* DB node map to send query */
-	int  virtual_master_node_id;	/* the first DB node to send query */
-	POOL_MEMORY_POOL *memory_context;	/* memory context for query */
-
-	/*
-	 * query_state:
-	 * 0: before parse   1: parse done     2: bind done
-	 * 3: describe done  4: execute done  -1: in error
-	 */
-	short query_state[MAX_NUM_BACKENDS];
-
+	bool where_to_send[MAX_NUM_BACKENDS];	/* DB node map to send query */
+	int  virtual_master_node_id;	   		/* the 1st DB node to send query */
+	POOL_MEMORY_POOL *memory_context;		/* memory context for query */
+	POOL_QUERY_STATE query_state[MAX_NUM_BACKENDS];	/* for extended query protocol */
 } POOL_QUERY_CONTEXT;
 
 extern POOL_QUERY_CONTEXT *pool_init_query_context(void);
@@ -69,8 +69,9 @@ POOL_STATUS pool_send_and_wait(POOL_QUERY_CONTEXT *query_context, char *query, i
 							   int send_type, int node_id, char *kind);
 extern Node *pool_get_parse_tree(void);
 extern char *pool_get_query_string(void);
-extern bool is_set_transaction_serializable(Node *ndoe, char *query);
-extern bool is_2pc_transaction_query(Node *node, char *query);
-extern void pool_set_query_state(POOL_QUERY_CONTEXT *query_context, short state);
+extern bool is_set_transaction_serializable(Node *node, char *query);
+extern bool is_2pc_transaction_query(Node *node);
+extern void pool_set_query_state(POOL_QUERY_CONTEXT *query_context, POOL_QUERY_STATE state);
+extern int statecmp(POOL_QUERY_STATE s1, POOL_QUERY_STATE s2);
 
 #endif /* POOL_QUERY_CONTEXT_H */
